@@ -281,12 +281,13 @@ def build_bgp(anm):
 #TODO: set this for vis
 # and set label back
     ibgp_label_to_level = {
-            None: "1", # Not set -> default
-            "None": 0, # Explicitly set role to "None" -> Not in iBGP
-            "RR":  3,
-            "RRC": 1,
-            "HRR": 2,
+            0: "None", # Explicitly set role to "None" -> Not in iBGP
+            3: "RR",
+            1: "RRC",
+            2: "HRR",
             }
+    for node in G_bgp:
+        node.ibgp_role = ibgp_label_to_level[node.ibgp_level]
 
     ebgp_nodes = [d for d in G_bgp if any(edge.type == 'ebgp' for edge in d.edges())]
     G_bgp.update(ebgp_nodes, ebgp=True)
